<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/core
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 *  If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Core;

use JchOptimize\Container;
use Psr\Log\LoggerInterface;
use function ob_get_clean;
use function var_dump;
abstract class Debugger
{
    public static function printr($var, $label = null)
    {
        self::debug('printr', $var, $label);
    }
    public static function vdump($var, $label = null)
    {
        self::debug('vdump', $var, $label);
    }
    private static function debug($method, $var, $label = null)
    {
        /** @var LoggerInterface $logger */
        $logger = Container::getInstance()->get(LoggerInterface::class);
        if (\is_null($label)) {
            $name = '';
        } else {
            $name = $label . ': ';
        }
        switch ($method) {
            case 'vdump':
                \ob_start();
                var_dump($var);
                $logger->debug($name . ob_get_clean());
                break;
            case 'printr':
            default:
                $logger->debug($name . \print_r($var, \true));
                break;
        }
    }
}
